dls-bxflow-epsic
=======================================================================

Bxflow beamline library for B24.

Wraps core science algorithms as runnable tasks for workflow execution.

Also implements the filesystem naming conventions at the beamline.

See http://www.cs.diamond.ac.uk/reports/gitlab-ci/dls-bxflow-epsic-workflows/index.html for how to install and run workflows.

..
    Anything below this line is used when viewing README.rst and will be replaced
    when included in index.rst


Documentation
-----------------------------------------------------------------------

See http://www.cs.diamond.ac.uk/reports/gitlab-ci/dls-bxflow-epsic/index.html for more detailed documentation on this package.

